@@ -4,8 +4,10 @@ import json
 from warnings import warn
 
 from django import forms
-from django.utils.safestring import mark_safe
 from django.contrib.admin.widgets import AdminFileWidget
+from django.db.models.fields.files import ImageFieldFile
+from django.utils.safestring import mark_safe
+from django.utils.translation import ugettext_lazy as _
 
 from fiber.app_settings import DETAIL_THUMBNAIL_OPTIONS
 from fiber.utils.images import get_thumbnail
@@ -89,10 +91,14 @@ class AdminImageWidgetWithPreview(AdminFileWidget):
     """
     def render(self, name, value, attrs=None):
         output = []
-        if value:
+        if value and isinstance(value, ImageFieldFile):
             file_name = str(value)
             thumbnail = get_thumbnail(file_name, thumbnail_options=DETAIL_THUMBNAIL_OPTIONS)
             if thumbnail:
-                output.append('<img src="{0}" width="{1}" height="{2}" />'.format(thumbnail.url, thumbnail.width, thumbnail.height))
+                try:
+                    output.append('<img src="{0}" width="{1}" height="{2}" />'.format(thumbnail.url, thumbnail.width, thumbnail.height))
+                except IOError:
+                    # original image file is missing
+                    output.append(_('<p>{0}</p>').format('Image file is missing'))
         output.append(super(AdminImageWidgetWithPreview, self).render(name, value, attrs))
         return mark_safe(u''.join(output))
